==> rmc-calendar-0.0.1.tgz: package/es/calendar/Header.js <==
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";
import _possibleConstructorReturn from "babel-runtime/helpers/possibleConstructorReturn";
import _inherits from "babel-runtime/helpers/inherits";
import * as React from 'react';

var Header = function (_React$PureComponent) {
    _inherits(Header, _React$PureComponent);

    function Header() {
        _classCallCheck(this, Header);

        var _this = _possibleConstructorReturn(this, (Header.__proto__ || Object.getPrototypeOf(Header)).apply(this, arguments));

        _this.setFPS = function (dom) {
            if (!_this.fps) {
                _this.fps = dom;
                var time = +new Date();
                var count = 0;
                var raf = function raf() {
                    return requestAnimationFrame(function () {
                        var now = +new Date();
                        if (now - time > 1 * 1000) {
                            dom.innerText = "JS FPS: " + count;
                            count = 0;
                            time = now;
                            console.log(dom.innerText);
                        } else {
                            count++;
                        }
                        raf();
                    });
                };
                raf();
            }
        };
        return _this;
    }

    _createClass(Header, [{
        key: "render",
        value: function render() {
            var _props = this.props,
                title = _props.title,
                _props$locale = _props.locale,
                locale = _props$locale === undefined ? {} : _props$locale,
                onCancel = _props.onCancel,
                onClear = _props.onClear,
                showClear = _props.showClear;

            return React.createElement(
                "div",
                { className: "header" },
                React.createElement(
                    "span",
                    { className: "left", onClick: function onClick() {
                            return onCancel && onCancel();
                        } },
                    "X"
                ),
                React.createElement(
                    "span",
                    { className: "title" },
                    title || locale.title
                ),
                showClear && React.createElement(
                    "span",
                    { className: "right", onClick: function onClick() {
                            return onClear && onClear();
                        } },
                    locale.clear
                )
            );
        }
    }]);

    return Header;
}(React.PureComponent);

export default Header;

==> rmc-calendar-0.1.6.tgz: package/es/calendar/Header.js <==
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";
import _possibleConstructorReturn from "babel-runtime/helpers/possibleConstructorReturn";
import _inherits from "babel-runtime/helpers/inherits";
import * as React from 'react';

var Header = function (_React$PureComponent) {
    _inherits(Header, _React$PureComponent);

    function Header() {
        _classCallCheck(this, Header);

        return _possibleConstructorReturn(this, (Header.__proto__ || Object.getPrototypeOf(Header)).apply(this, arguments));
    }

    _createClass(Header, [{
        key: "render",
        value: function render() {
            var _props = this.props,
                title = _props.title,
                _props$locale = _props.locale,
                locale = _props$locale === undefined ? {} : _props$locale,
                onCancel = _props.onCancel,
                onClear = _props.onClear,
                showClear = _props.showClear;

            return React.createElement(
                "div",
                { className: "header" },
                React.createElement(
                    "span",
                    { className: "left", onClick: function onClick() {
                            return onCancel && onCancel();
                        } },
                    "X"
                ),
                React.createElement(
                    "span",
                    { className: "title" },
                    title || locale.title
                ),
                showClear && React.createElement(
                    "span",
                    { className: "right", onClick: function onClick() {
                            return onClear && onClear();
                        } },
                    locale.clear
                )
            );
        }
    }]);

    return Header;
}(React.PureComponent);

export default Header;
